OrbitalMissingDependencyException class final
Thrown when a dependency lookup cannot be satisfied from the scope tree.
- Inheritance
-
- Object
- OrbitalException
- OrbitalMissingDependencyException
Constructors
- OrbitalMissingDependencyException(Type type, OrbitalKey? key)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited